smartcard.wx.ReaderToolbar.ReaderComboBox

# ``smartcard`.`wx`.`ReaderToolbar`.`ReaderComboBox``

class documentation

`class ReaderComboBox(wx.ComboBox, ReaderObserver):`

View In Hierarchy

Undocumented

Method | `__init__` | Constructor. Registers as ReaderObserver to get notifications of reader insertion/removal.
Method | `update` | Toolbar ReaderObserver callback that is notified when readers are added or removed.
Instance Variable | `readermonitor` | Undocumented

def __init__(self, parent):
overrides `smartcard.ReaderMonitoring.ReaderObserver.__init__`

Constructor. Registers as ReaderObserver to get notifications of reader insertion/removal.

def update(self, observable, handlers):
overrides `smartcard.ReaderMonitoring.ReaderObserver.update`

Toolbar ReaderObserver callback that is notified when readers are added or removed.

readermonitor =

Undocumented